==> beast-kit-redis-1.0.5-sources.jar: com/thebeastshop/kit/redis/springboot/RedisAutoConfiguration.java <==
package com.thebeastshop.kit.redis.springboot;

import com.thebeastshop.kit.prop.PropConstants;
import com.thebeastshop.kit.redis.lock.RedisDistributLock;
import com.thebeastshop.kit.redis.script.RedisScriptScanner;
import com.thebeastshop.kit.redis.util.RedisClient;
import org.redisson.Redisson;
import org.redisson.api.RedissonClient;
import org.redisson.config.Config;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

/**
 * @author Bryan.Zhang
 * @Date 2019-03-20
 */
@Configuration
@ConditionalOnProperty(name = "redis.sentinel.address")
public class RedisAutoConfiguration {

    private final Logger log = LoggerFactory.getLogger(getClass());

    private final static String REDIS_MASTER_NAME = "redis.master.name";
    private final static String REDIS_SENTINEL_ADDRESS = "redis.sentinel.address";
    private final static String REDIS_PASSWORD = "redis.password";
    private final static String REDIS_DBINDEX = "redis.dbindex";
    private final static String REDIS_MASTER_MIN_IDLE_SIZE = "redis.master.min.idle.size";
    private final static String REDIS_MASTER_POOL_SIZE = "redis.master.pool.size";
    private final static String REDIS_SLAVE_POOL_SIZE = "redis.slave.pool.size";
    private final static String REDIS_SLAVE_MIN_IDLE_SIZE = "redis.slave.min.idle.size";

    @Bean
    public RedissonClient redissonClient(){
        log.info("开始redis的自动初始化,哨兵地址{}",PropConstants.getProperties(REDIS_SENTINEL_ADDRESS));
        Config config = new Config();
        config.useSentinelServers().setMasterName(PropConstants.getProperties(REDIS_MASTER_NAME))
                .addSentinelAddress(PropConstants.getProperties(REDIS_SENTINEL_ADDRESS))
                .setDatabase(Integer.parseInt(PropConstants.getProperties(REDIS_DBINDEX)))
                .setPassword(PropConstants.getProperties(REDIS_PASSWORD))
                .setMasterConnectionPoolSize(Integer.parseInt(PropConstants.getProperties(REDIS_MASTER_POOL_SIZE)))
                .setMasterConnectionMinimumIdleSize(Integer.parseInt(PropConstants.getProperties(REDIS_MASTER_MIN_IDLE_SIZE)))
                .setSlaveConnectionPoolSize(Integer.parseInt(PropConstants.getProperties(REDIS_SLAVE_POOL_SIZE)))
                .setSlaveConnectionMinimumIdleSize(Integer.parseInt(PropConstants.getProperties(REDIS_SLAVE_MIN_IDLE_SIZE)));
        RedissonClient redissonClient = Redisson.create(config);
        return redissonClient;
    }

    @Bean
    public RedisClient redisClient(RedissonClient redissonClient){
        RedisClient redisClient = new RedisClient(redissonClient);
        return redisClient;
    }

    @Bean
    public RedisDistributLock redisDistributLock(RedissonClient redissonClient){
        RedisDistributLock redisDistributLock = new RedisDistributLock(redissonClient);
        return redisDistributLock;
    }

    @Bean
    public RedisScriptScanner redisScriptScanner(RedissonClient redissonClient){
        RedisScriptScanner redisScriptScanner = new RedisScriptScanner(redissonClient,"classpath*:lua/*.lua");
        return redisScriptScanner;
    }

}

==> beast-kit-redis-1.0.7-20200408.072954-1-sources.jar: com/thebeastshop/kit/redis/springboot/RedisAutoConfiguration.java <==
package com.thebeastshop.kit.redis.springboot;

import com.thebeastshop.kit.redis.lock.RedisDistributLock;
import com.thebeastshop.kit.redis.script.RedisScriptScanner;
import com.thebeastshop.kit.redis.util.RedisClient;
import org.redisson.Redisson;
import org.redisson.api.RedissonClient;
import org.redisson.config.Config;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.Environment;

/**
 * @author Bryan.Zhang
 * @Date 2019-03-20
 */
@Configuration
@ConditionalOnProperty(name = "redis.sentinel.address")
public class RedisAutoConfiguration {

    private final Logger log = LoggerFactory.getLogger(getClass());

    private final static String REDIS_MASTER_NAME = "redis.master.name";
    private final static String REDIS_SENTINEL_ADDRESS = "redis.sentinel.address";
    private final static String REDIS_PASSWORD = "redis.password";
    private final static String REDIS_DBINDEX = "redis.dbindex";
    private final static String REDIS_MASTER_MIN_IDLE_SIZE = "redis.master.min.idle.size";
    private final static String REDIS_MASTER_POOL_SIZE = "redis.master.pool.size";
    private final static String REDIS_SLAVE_POOL_SIZE = "redis.slave.pool.size";
    private final static String REDIS_SLAVE_MIN_IDLE_SIZE = "redis.slave.min.idle.size";

    @Bean
    public RedissonClient redissonClient(Environment environment){
        log.info("开始redis的自动初始化,哨兵地址{}",environment.getProperty(REDIS_SENTINEL_ADDRESS));
        Config config = new Config();
        config.useSentinelServers().setMasterName(environment.getProperty(REDIS_MASTER_NAME))
                .addSentinelAddress(environment.getProperty(REDIS_SENTINEL_ADDRESS))
                .setDatabase(Integer.parseInt(environment.getProperty(REDIS_DBINDEX)))
                .setPassword(environment.getProperty(REDIS_PASSWORD))
                .setMasterConnectionPoolSize(Integer.parseInt(environment.getProperty(REDIS_MASTER_POOL_SIZE)))
                .setMasterConnectionMinimumIdleSize(Integer.parseInt(environment.getProperty(REDIS_MASTER_MIN_IDLE_SIZE)))
                .setSlaveConnectionPoolSize(Integer.parseInt(environment.getProperty(REDIS_SLAVE_POOL_SIZE)))
                .setSlaveConnectionMinimumIdleSize(Integer.parseInt(environment.getProperty(REDIS_SLAVE_MIN_IDLE_SIZE)));
        RedissonClient redissonClient = Redisson.create(config);
        return redissonClient;
    }

    @Bean
    public RedisClient redisClient(RedissonClient redissonClient){
        RedisClient redisClient = new RedisClient(redissonClient);
        return redisClient;
    }

    @Bean
    public RedisDistributLock redisDistributLock(RedissonClient redissonClient){
        RedisDistributLock redisDistributLock = new RedisDistributLock(redissonClient);
        return redisDistributLock;
    }

    @Bean
    public RedisScriptScanner redisScriptScanner(RedissonClient redissonClient){
        RedisScriptScanner redisScriptScanner = new RedisScriptScanner(redissonClient,"classpath*:lua/*.lua");
        return redisScriptScanner;
    }

}
